==> com.liferay.layout.content.page.editor.web-2.0.74.jar: META-INF/resources/page_editor/app/components/undo/undoAddFragmentEntryLinks.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.74/page_editor/app/components/undo/undoAddFragmentEntryLinks", ['module', 'exports', 'require', '../../thunks/deleteItem'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.undoAction = undoAction;
    exports.getDerivedStateForUndo = getDerivedStateForUndo;

    var _deleteItem = _interopRequireDefault(require("../../thunks/deleteItem"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function undoAction(_ref) {
      var action = _ref.action,
          store = _ref.store;
      return (0, _deleteItem["default"])(_objectSpread({}, action, {
        store: store
      }));
    }

    function getDerivedStateForUndo(_ref2) {
      var action = _ref2.action;
      return {
        itemId: action.itemId
      };
    }
    //# sourceMappingURL=undoAddFragmentEntryLinks.js.map
  }
});
//# sourceMappingURL=undoAddFragmentEntryLinks.js.map

==> com.liferay.layout.content.page.editor.web-2.0.122.jar: META-INF/resources/page_editor/app/components/undo/undoAddFragmentEntryLinks.js <==
Liferay.Loader.define("layout-content-page-editor-web@2.0.122/page_editor/app/components/undo/undoAddFragmentEntryLinks", ['module', 'exports', 'require', '../../thunks/deleteItem'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.undoAction = undoAction;
    exports.getDerivedStateForUndo = getDerivedStateForUndo;

    var _deleteItem = _interopRequireDefault(require("../../thunks/deleteItem"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function ownKeys(object, enumerableOnly) {
      var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
          return Object.getOwnPropertyDescriptor(object, sym).enumerable;
        });keys.push.apply(keys, symbols);
      }return keys;
    }

    function _objectSpread(target) {
      for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
          ownKeys(Object(source), true).forEach(function (key) {
            _defineProperty(target, key, source[key]);
          });
        } else if (Object.getOwnPropertyDescriptors) {
          Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
        } else {
          ownKeys(Object(source)).forEach(function (key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
          });
        }
      }return target;
    }

    function _defineProperty(obj, key, value) {
      if (key in obj) {
        Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
      } else {
        obj[key] = value;
      }return obj;
    }

    function undoAction(_ref) {
      var action = _ref.action,
          store = _ref.store;
      return (0, _deleteItem.default)(_objectSpread(_objectSpread({}, action), {}, {
        store: store
      }));
    }

    function getDerivedStateForUndo(_ref2) {
      var action = _ref2.action;
      return {
        itemId: action.itemId
      };
    }
    //# sourceMappingURL=undoAddFragmentEntryLinks.js.map
  }
});
//# sourceMappingURL=undoAddFragmentEntryLinks.js.map
